==> haskell-th-extras-0.0.0.8-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-th-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-extras
version:              0.0.0.8
visibility:           public
id:                   th-extras-0.0.0.8-5PsGX1LsYHJAeBIfbdBVCt
key:                  th-extras-0.0.0.8-5PsGX1LsYHJAeBIfbdBVCt
license:              LicenseRef-PublicDomain
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/erikd/th-extras
synopsis:             A grab bag of functions for use with Template Haskell
description:
    A grab bag of functions for use with Template Haskell.

    This is basically the place I put all my ugly CPP hacks to support
    the ever-changing interface of the template haskell system by
    providing high-level operations and making sure they work on as many
    versions of Template Haskell as I can.

category:             Template Haskell
abi:                  d2011a478892b5bbf10118c23bdbc486
exposed:              True
exposed-modules:      Language.Haskell.TH.Extras
import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-extras-0.0.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-extras-0.0.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-extras
hs-libraries:         HSth-extras-0.0.0.8-5PsGX1LsYHJAeBIfbdBVCt
depends:
    base-4.16.4.0 containers-0.6.5.1 syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s
    template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu

haddock-interfaces:   /usr/share/doc/haskell-th-extras/html/th-extras.haddock
haddock-html:         /usr/share/doc/haskell-th-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-extras-0.0.0.8-33.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-th-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-extras
version:              0.0.0.8
visibility:           public
id:                   th-extras-0.0.0.8-Jd5S2uidOAX8XkBJaSzGg7
key:                  th-extras-0.0.0.8-Jd5S2uidOAX8XkBJaSzGg7
license:              LicenseRef-PublicDomain
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/erikd/th-extras
synopsis:             A grab bag of functions for use with Template Haskell
description:
    A grab bag of functions for use with Template Haskell.

    This is basically the place I put all my ugly CPP hacks to support
    the ever-changing interface of the template haskell system by
    providing high-level operations and making sure they work on as many
    versions of Template Haskell as I can.

category:             Template Haskell
abi:                  e7b3bdb988123c73c8312aa7d5e6c55d
exposed:              True
exposed-modules:      Language.Haskell.TH.Extras
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-extras-0.0.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-extras-0.0.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-extras-0.0.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-extras
hs-libraries:         HSth-extras-0.0.0.8-Jd5S2uidOAX8XkBJaSzGg7
depends:
    base-4.17.2.1 containers-0.6.7 syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:   /usr/share/doc/haskell-th-extras/html/th-extras.haddock
haddock-html:         /usr/share/doc/haskell-th-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
